import os
from dotenv import load_dotenv

# Carregar variáveis de ambiente do arquivo .env
load_dotenv()

# Definir os valores padrão para as configurações
DEFAULT_CONFIG = {
    "DMT_LOG_PATH": "data/logs/[now %Y]/[now %m.%b]/[now %d.%a]/[now %H]h/{log_name}.log",
    "DMT_LOG_TEMPLATE": "%(asctime)s [{log_name}] - %(levelname)s - %(message)s",
    "DMT_LOG_TIME_FORMAT": "%H:%M:%S",
    "DMT_LOG_LEVEL": "INFO"
}

def add_config_section(file_path: str, section_name: str, config_dict: dict):
    """
    Adiciona uma nova seção no arquivo .env com as configurações fornecidas.
    
    :param file_path: Caminho para o arquivo .env
    :param section_name: Nome da seção a ser adicionada (ex: 'Configurações da biblioteca DMTLogger')
    :param config_dict: Dicionário contendo as variáveis de configuração (chave: valor)
    """
    # Verifica se a seção já existe no arquivo .env
    if section_exists(file_path, section_name):
        return

    # Adiciona a seção ao arquivo .env
    with open(file_path, "a") as file:
        file.write(f"\n# {section_name}\n")
        for key, value in config_dict.items():
            file.write(f"{key}='{value}'\n")
    print(f"Seção '{section_name}' adicionada ao arquivo .env.")

def section_exists(file_path: str, section_name: str) -> bool:
    """Verifica se uma seção já existe no arquivo .env"""
    if not os.path.exists(file_path):
        return
    with open(file_path, "r") as file:
        lines = file.readlines()
        section_header = f"# {section_name}"
        return any(section_header in line for line in lines)

# Função para obter o valor de uma variável de ambiente com fallback para o valor padrão
def get_config_value(key: str, default_value: str) -> str:
    """
    Obtém o valor de uma variável de ambiente ou retorna o valor padrão.
    
    :param key: A chave da variável de ambiente
    :param default_value: Valor padrão a ser retornado caso a variável não esteja definida
    :return: Valor da variável de ambiente ou o valor padrão
    """
    return os.getenv(key, default_value)

# Exemplo de uso
env_file_path = ".env"

# Dicionário com as configurações a serem adicionadas
add_config_section(env_file_path, "DMTLogger config --- Read more in dmt_logger/README.md --- do not remove this line", DEFAULT_CONFIG)

# Carregar configurações das variáveis de ambiente com fallback
DMT_LOG_PATH = get_config_value("DMT_LOG_PATH", DEFAULT_CONFIG["DMT_LOG_PATH"])
DMT_LOG_TEMPLATE = get_config_value("DMT_LOG_TEMPLATE", DEFAULT_CONFIG["DMT_LOG_TEMPLATE"])
DMT_LOG_TIME_FORMAT = get_config_value("DMT_LOG_TIME_FORMAT", DEFAULT_CONFIG["DMT_LOG_TIME_FORMAT"])
DMT_LOG_LEVEL = get_config_value("DMT_LOG_LEVEL", DEFAULT_CONFIG["DMT_LOG_LEVEL"])

