# logger.py
import logging
import locale
from datetime import datetime
from pathlib import Path
import re
from .config import DMT_LOG_TEMPLATE, DMT_LOG_TIME_FORMAT, DMT_LOG_LEVEL, DMT_LOG_PATH

# Define o locale para português do Brasil
try:
    locale.setlocale(locale.LC_TIME, 'pt_BR.utf8')
except locale.Error:
    print("Locale 'pt_BR.utf8' não disponível. Usando o padrão do sistema.")

class LoggerObj(logging.Logger):
    def __init__(self, name: str, log_path: str = DMT_LOG_PATH, log_level: int = DMT_LOG_LEVEL, 
                 log_template: str = DMT_LOG_TEMPLATE, time_format: str = DMT_LOG_TIME_FORMAT):
        """
        Classe Logger personalizada com suporte a templates dinâmicos.

        :param name: Nome do logger.
        :param log_path: Caminho do arquivo de log. Pode conter placeholders dinâmicos.
        :param log_level: Nível de log (INFO, DEBUG, etc.).
        :param log_template: Template de formatação do log.
        :param time_format: Formato da hora no log.
        """
        super().__init__(name, log_level)
        self.log_path = log_path.format(log_name=name)
        log_template = log_template.format(log_name=name.split(".")[-1])
        self.logging_path = self._setup_logger(log_template, time_format, log_level)
        self.logger_format = self.handlers[0].formatter

    def _setup_logger(self, log_format: str, time_format: str, log_level: int) -> str:
        """Configura o logger e define o arquivo de saída."""
        log_path = self._generate_log_path()

        # Verifica se o handler já foi adicionado para evitar duplicações
        if not any(isinstance(h, logging.FileHandler) and h.baseFilename == log_path for h in self.handlers):
            file_handler = logging.FileHandler(log_path, encoding="utf-8")
            file_handler.setLevel(log_level)
            file_handler.setFormatter(logging.Formatter(log_format, time_format))
            self.addHandler(file_handler)

        self.setLevel(log_level)
        self.propagate = False
        return log_path

    def _generate_log_path(self) -> str:
        """Gera o caminho correto do arquivo de log baseado no template e formatação dinâmica."""
        now = datetime.now()

        # Função para substituir a expressão de data [now ...] pela data formatada
        def replace_match(match):
            date_format = match.group(1)
            return now.strftime(date_format).replace(" ", "_")  # Evita espaços no caminho

        # Imprime para depuração
        print(f"Log Path Inicial: {self.log_path}")

        # Extrai o nome do arquivo (última parte do caminho)
        filename = self.log_path.split("/")[-1]
        
        # Substitui os pontos no nome do arquivo por barras para criar as pastas
        filename_with_folders = filename.replace(".log", "").replace(".", "/") + ".log"
        
        # Substitui o nome do arquivo original pelo nome com as pastas criadas
        log_path = self.log_path.replace(filename, filename_with_folders)

        # Aplica a substituição de data no caminho do log
        log_path = re.sub(r"\[now (.*?)\]", replace_match, log_path)

        # Cria o diretório do log, se não existir
        log_folder = Path(log_path).parent
        log_folder.mkdir(parents=True, exist_ok=True)

        return log_path
    
    def _log_with_temp_format(self, level, msg, *args, temp_format: str = None, **kwargs):
        # Se temp_format for fornecido, altera o formatador
        if temp_format:
            self.handlers[0].setFormatter(logging.Formatter(temp_format, '%H:%M:%S'))
        
        # Chama o método de log da classe pai
        super()._log(level, msg, args, **kwargs)
        
        # Restaura o formatador original
        if temp_format:
            self.handlers[0].setFormatter(self.logger_format)

    def info(self, msg, *args, temp_format: str = None, **kwargs) -> None:
        self._log_with_temp_format(logging.INFO, msg, *args, temp_format=temp_format, **kwargs)

    def error(self, msg, *args, temp_format: str = None, **kwargs) -> None:
        self._log_with_temp_format(logging.ERROR, msg, *args, temp_format=temp_format, **kwargs)

    def debug(self, msg, *args, temp_format: str = None, **kwargs) -> None:
        self._log_with_temp_format(logging.DEBUG, msg, *args, temp_format=temp_format, **kwargs)

    def warning(self, msg, *args, temp_format: str = None, **kwargs) -> None:
        self._log_with_temp_format(logging.WARNING, msg, *args, temp_format=temp_format, **kwargs)

    def exception(self, msg, *args, temp_format: str = None, **kwargs) -> None:
        self._log_with_temp_format(logging.ERROR, msg, *args, temp_format=temp_format, exc_info=True, **kwargs)
